# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from payjpv2.models.product_create_request import ProductCreateRequest
from payjpv2.models.product_deleted_response import ProductDeletedResponse
from payjpv2.models.product_details_response import ProductDetailsResponse
from payjpv2.models.product_list_response import ProductListResponse
from payjpv2.models.product_update_request import ProductUpdateRequest

from payjpv2.api_client import ApiClient, RequestSerialized
from payjpv2.api_response import ApiResponse
from payjpv2.rest import RESTResponseType


class ProductsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_product(
        self,
        product_create_request: ProductCreateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ProductDetailsResponse:
        """Create Product


        :param product_create_request: (required)
        :type product_create_request: ProductCreateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_product_serialize(
            product_create_request=product_create_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_product_with_http_info(
        self,
        product_create_request: ProductCreateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ProductDetailsResponse]:
        """Create Product


        :param product_create_request: (required)
        :type product_create_request: ProductCreateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_product_serialize(
            product_create_request=product_create_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_product_without_preload_content(
        self,
        product_create_request: ProductCreateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Product


        :param product_create_request: (required)
        :type product_create_request: ProductCreateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_product_serialize(
            product_create_request=product_create_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        return response_data.response


    def _create_product_serialize(
        self,
        product_create_request,
        _request_auth,
        _content_type,
        _headers,
        _idempotency_key,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        if _idempotency_key is not None:
            _header_params['Idempotency-Key'] = _idempotency_key
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if product_create_request is not None:
            _body_params = product_create_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/problem+json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBasic', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/products',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_product(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ProductDeletedResponse:
        """Delete Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDeletedResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_product_with_http_info(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ProductDeletedResponse]:
        """Delete Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDeletedResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_product_without_preload_content(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDeletedResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        return response_data.response


    def _delete_product_serialize(
        self,
        product_id,
        _request_auth,
        _content_type,
        _headers,
        _idempotency_key,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        if _idempotency_key is not None:
            _header_params['Idempotency-Key'] = _idempotency_key
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if product_id is not None:
            _path_params['product_id'] = product_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/problem+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBasic', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v2/products/{product_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_all_products(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="取得するデータの最大件数")] = None,
        starting_after: Annotated[Optional[StrictStr], Field(description="このIDより後のデータを取得")] = None,
        ending_before: Annotated[Optional[StrictStr], Field(description="このIDより前のデータを取得")] = None,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ProductListResponse:
        """Get All Products


        :param limit: 取得するデータの最大件数
        :type limit: int
        :param starting_after: このIDより後のデータを取得
        :type starting_after: str
        :param ending_before: このIDより前のデータを取得
        :type ending_before: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_products_serialize(
            limit=limit,
            starting_after=starting_after,
            ending_before=ending_before,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductListResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_all_products_with_http_info(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="取得するデータの最大件数")] = None,
        starting_after: Annotated[Optional[StrictStr], Field(description="このIDより後のデータを取得")] = None,
        ending_before: Annotated[Optional[StrictStr], Field(description="このIDより前のデータを取得")] = None,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ProductListResponse]:
        """Get All Products


        :param limit: 取得するデータの最大件数
        :type limit: int
        :param starting_after: このIDより後のデータを取得
        :type starting_after: str
        :param ending_before: このIDより前のデータを取得
        :type ending_before: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_products_serialize(
            limit=limit,
            starting_after=starting_after,
            ending_before=ending_before,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductListResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_all_products_without_preload_content(
        self,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="取得するデータの最大件数")] = None,
        starting_after: Annotated[Optional[StrictStr], Field(description="このIDより後のデータを取得")] = None,
        ending_before: Annotated[Optional[StrictStr], Field(description="このIDより前のデータを取得")] = None,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get All Products


        :param limit: 取得するデータの最大件数
        :type limit: int
        :param starting_after: このIDより後のデータを取得
        :type starting_after: str
        :param ending_before: このIDより前のデータを取得
        :type ending_before: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_products_serialize(
            limit=limit,
            starting_after=starting_after,
            ending_before=ending_before,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductListResponse",
            '422': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        return response_data.response


    def _get_all_products_serialize(
        self,
        limit,
        starting_after,
        ending_before,
        _request_auth,
        _content_type,
        _headers,
        _idempotency_key,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        if _idempotency_key is not None:
            _header_params['Idempotency-Key'] = _idempotency_key
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if starting_after is not None:
            
            _query_params.append(('starting_after', starting_after))
            
        if ending_before is not None:
            
            _query_params.append(('ending_before', ending_before))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/problem+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBasic', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/products',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_product(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ProductDetailsResponse:
        """Get Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_product_with_http_info(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ProductDetailsResponse]:
        """Get Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_product_without_preload_content(
        self,
        product_id: StrictStr,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Product


        :param product_id: (required)
        :type product_id: str
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_product_serialize(
            product_id=product_id,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        return response_data.response


    def _get_product_serialize(
        self,
        product_id,
        _request_auth,
        _content_type,
        _headers,
        _idempotency_key,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        if _idempotency_key is not None:
            _header_params['Idempotency-Key'] = _idempotency_key
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if product_id is not None:
            _path_params['product_id'] = product_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/problem+json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBasic', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/products/{product_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_product(
        self,
        product_id: StrictStr,
        product_update_request: ProductUpdateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ProductDetailsResponse:
        """Update Product


        :param product_id: (required)
        :type product_id: str
        :param product_update_request: (required)
        :type product_update_request: ProductUpdateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_product_serialize(
            product_id=product_id,
            product_update_request=product_update_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_product_with_http_info(
        self,
        product_id: StrictStr,
        product_update_request: ProductUpdateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ProductDetailsResponse]:
        """Update Product


        :param product_id: (required)
        :type product_id: str
        :param product_update_request: (required)
        :type product_update_request: ProductUpdateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_product_serialize(
            product_id=product_id,
            product_update_request=product_update_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_product_without_preload_content(
        self,
        product_id: StrictStr,
        product_update_request: ProductUpdateRequest,
        *,
        request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth: Optional[Dict[StrictStr, Any]] = None,
        headers: Optional[Dict[StrictStr, Any]] = None,
        idempotency_key: Optional[StrictStr] = None,
        host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Product


        :param product_id: (required)
        :type product_id: str
        :param product_update_request: (required)
        :type product_update_request: ProductUpdateRequest
        :param request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type request_timeout: int, tuple(int, int), optional
        :param request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type request_auth: dict, optional
        :param headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type headers: dict, optional
        :param idempotency_key: an idempotency key for the request.
                                 used to ensure the request is only processed once.
        :type idempotency_key: str, optional
        :param host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_product_serialize(
            product_id=product_id,
            product_update_request=product_update_request,
            _request_auth=request_auth,
            _content_type='application/json',
            _headers=headers,
            _idempotency_key=idempotency_key,
            _host_index=host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ProductDetailsResponse",
            '422': "ErrorResponse",
            '404': "ErrorResponse",
            '400': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=request_timeout
        )
        return response_data.response


    def _update_product_serialize(
        self,
        product_id,
        product_update_request,
        _request_auth,
        _content_type,
        _headers,
        _idempotency_key,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        if _idempotency_key is not None:
            _header_params['Idempotency-Key'] = _idempotency_key
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if product_id is not None:
            _path_params['product_id'] = product_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if product_update_request is not None:
            _body_params = product_update_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/problem+json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBasic', 
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/products/{product_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from payjpv2.models.balance_list_response import BalanceListResponse
from payjpv2.models.balance_response import BalanceResponse
from payjpv2.models.balance_state import BalanceState
from payjpv2.models.balance_url_response import BalanceURLResponse
from payjpv2.models.bank_info_response import BankInfoResponse
from payjpv2.models.capture_method import CaptureMethod
from payjpv2.models.card_config_request import CardConfigRequest
from payjpv2.models.checkout_session_create_request import CheckoutSessionCreateRequest
from payjpv2.models.checkout_session_customer_details_address_response import CheckoutSessionCustomerDetailsAddressResponse
from payjpv2.models.checkout_session_customer_details_response import CheckoutSessionCustomerDetailsResponse
from payjpv2.models.checkout_session_details_response import CheckoutSessionDetailsResponse
from payjpv2.models.checkout_session_line_item_data_response import CheckoutSessionLineItemDataResponse
from payjpv2.models.checkout_session_line_item_list_response import CheckoutSessionLineItemListResponse
from payjpv2.models.checkout_session_list_response import CheckoutSessionListResponse
from payjpv2.models.checkout_session_mode import CheckoutSessionMode
from payjpv2.models.checkout_session_payment_method_options_card_request import CheckoutSessionPaymentMethodOptionsCardRequest
from payjpv2.models.checkout_session_payment_method_options_request import CheckoutSessionPaymentMethodOptionsRequest
from payjpv2.models.checkout_session_status import CheckoutSessionStatus
from payjpv2.models.checkout_session_submit_type import CheckoutSessionSubmitType
from payjpv2.models.checkout_session_ui_mode import CheckoutSessionUIMode
from payjpv2.models.checkout_session_update_request import CheckoutSessionUpdateRequest
from payjpv2.models.country import Country
from payjpv2.models.currency import Currency
from payjpv2.models.customer_create_request import CustomerCreateRequest
from payjpv2.models.customer_creation import CustomerCreation
from payjpv2.models.customer_list_response import CustomerListResponse
from payjpv2.models.customer_response import CustomerResponse
from payjpv2.models.customer_update_request import CustomerUpdateRequest
from payjpv2.models.display_preference_request import DisplayPreferenceRequest
from payjpv2.models.error_response import ErrorResponse
from payjpv2.models.event_list_response import EventListResponse
from payjpv2.models.event_response import EventResponse
from payjpv2.models.line_item_request import LineItemRequest
from payjpv2.models.locale import Locale
from payjpv2.models.metadata_value import MetadataValue
from payjpv2.models.pay_pay_config_request import PayPayConfigRequest
from payjpv2.models.payment_flow_cancel_request import PaymentFlowCancelRequest
from payjpv2.models.payment_flow_cancellation_reason import PaymentFlowCancellationReason
from payjpv2.models.payment_flow_capture_request import PaymentFlowCaptureRequest
from payjpv2.models.payment_flow_confirm_request import PaymentFlowConfirmRequest
from payjpv2.models.payment_flow_create_request import PaymentFlowCreateRequest
from payjpv2.models.payment_flow_data_request import PaymentFlowDataRequest
from payjpv2.models.payment_flow_list_response import PaymentFlowListResponse
from payjpv2.models.payment_flow_payment_method_options_card_request import PaymentFlowPaymentMethodOptionsCardRequest
from payjpv2.models.payment_flow_payment_method_options_request import PaymentFlowPaymentMethodOptionsRequest
from payjpv2.models.payment_flow_response import PaymentFlowResponse
from payjpv2.models.payment_flow_status import PaymentFlowStatus
from payjpv2.models.payment_flow_update_request import PaymentFlowUpdateRequest
from payjpv2.models.payment_method_apple_pay_create_request import PaymentMethodApplePayCreateRequest
from payjpv2.models.payment_method_apple_pay_update_request import PaymentMethodApplePayUpdateRequest
from payjpv2.models.payment_method_attach_request import PaymentMethodAttachRequest
from payjpv2.models.payment_method_billing_address_request import PaymentMethodBillingAddressRequest
from payjpv2.models.payment_method_billing_address_response import PaymentMethodBillingAddressResponse
from payjpv2.models.payment_method_billing_details_request import PaymentMethodBillingDetailsRequest
from payjpv2.models.payment_method_billing_details_response import PaymentMethodBillingDetailsResponse
from payjpv2.models.payment_method_card_billing_details_request import PaymentMethodCardBillingDetailsRequest
from payjpv2.models.payment_method_card_create_request import PaymentMethodCardCreateRequest
from payjpv2.models.payment_method_card_details_response import PaymentMethodCardDetailsResponse
from payjpv2.models.payment_method_card_response import PaymentMethodCardResponse
from payjpv2.models.payment_method_card_update_request import PaymentMethodCardUpdateRequest
from payjpv2.models.payment_method_configuration_details_response import PaymentMethodConfigurationDetailsResponse
from payjpv2.models.payment_method_configuration_display_preference import PaymentMethodConfigurationDisplayPreference
from payjpv2.models.payment_method_configuration_list_response import PaymentMethodConfigurationListResponse
from payjpv2.models.payment_method_configuration_setting_response import PaymentMethodConfigurationSettingResponse
from payjpv2.models.payment_method_configuration_update_request import PaymentMethodConfigurationUpdateRequest
from payjpv2.models.payment_method_create_card_details_request import PaymentMethodCreateCardDetailsRequest
from payjpv2.models.payment_method_create_request import PaymentMethodCreateRequest
from payjpv2.models.payment_method_list_response import PaymentMethodListResponse
from payjpv2.models.payment_method_pay_pay_create_request import PaymentMethodPayPayCreateRequest
from payjpv2.models.payment_method_pay_pay_response import PaymentMethodPayPayResponse
from payjpv2.models.payment_method_pay_pay_update_request import PaymentMethodPayPayUpdateRequest
from payjpv2.models.payment_method_response import PaymentMethodResponse
from payjpv2.models.payment_method_types import PaymentMethodTypes
from payjpv2.models.payment_method_update_request import PaymentMethodUpdateRequest
from payjpv2.models.payment_refund_create_request import PaymentRefundCreateRequest
from payjpv2.models.payment_refund_list_response import PaymentRefundListResponse
from payjpv2.models.payment_refund_reason import PaymentRefundReason
from payjpv2.models.payment_refund_response import PaymentRefundResponse
from payjpv2.models.payment_refund_status import PaymentRefundStatus
from payjpv2.models.payment_refund_update_request import PaymentRefundUpdateRequest
from payjpv2.models.payment_transaction_list_response import PaymentTransactionListResponse
from payjpv2.models.payment_transaction_response import PaymentTransactionResponse
from payjpv2.models.payment_transaction_type import PaymentTransactionType
from payjpv2.models.price_create_request import PriceCreateRequest
from payjpv2.models.price_details_response import PriceDetailsResponse
from payjpv2.models.price_list_response import PriceListResponse
from payjpv2.models.price_type import PriceType
from payjpv2.models.price_update_request import PriceUpdateRequest
from payjpv2.models.product_create_request import ProductCreateRequest
from payjpv2.models.product_deleted_response import ProductDeletedResponse
from payjpv2.models.product_details_response import ProductDetailsResponse
from payjpv2.models.product_list_response import ProductListResponse
from payjpv2.models.product_update_request import ProductUpdateRequest
from payjpv2.models.setup_flow_cancel_request import SetupFlowCancelRequest
from payjpv2.models.setup_flow_cancellation_reason import SetupFlowCancellationReason
from payjpv2.models.setup_flow_create_request import SetupFlowCreateRequest
from payjpv2.models.setup_flow_data_request import SetupFlowDataRequest
from payjpv2.models.setup_flow_list_response import SetupFlowListResponse
from payjpv2.models.setup_flow_payment_method_options_card_request import SetupFlowPaymentMethodOptionsCardRequest
from payjpv2.models.setup_flow_payment_method_options_request import SetupFlowPaymentMethodOptionsRequest
from payjpv2.models.setup_flow_response import SetupFlowResponse
from payjpv2.models.setup_flow_status import SetupFlowStatus
from payjpv2.models.setup_flow_update_request import SetupFlowUpdateRequest
from payjpv2.models.statement_item_response import StatementItemResponse
from payjpv2.models.statement_list_response import StatementListResponse
from payjpv2.models.statement_response import StatementResponse
from payjpv2.models.statement_subject import StatementSubject
from payjpv2.models.statement_type import StatementType
from payjpv2.models.statement_url_response import StatementURLResponse
from payjpv2.models.tax_rate_create_request import TaxRateCreateRequest
from payjpv2.models.tax_rate_details_response import TaxRateDetailsResponse
from payjpv2.models.tax_rate_list_response import TaxRateListResponse
from payjpv2.models.tax_rate_update_request import TaxRateUpdateRequest
from payjpv2.models.term_list_response import TermListResponse
from payjpv2.models.term_response import TermResponse
from payjpv2.models.usage import Usage



# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.checkout_session_create_request import CheckoutSessionCreateRequest

class TestCheckoutSessionCreateRequest(unittest.TestCase):
    """CheckoutSessionCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckoutSessionCreateRequest:
        """Test CheckoutSessionCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckoutSessionCreateRequest`
        """
        model = CheckoutSessionCreateRequest()
        if include_optional:
            return CheckoutSessionCreateRequest(
                mode = 'payment',
                client_reference_id = '',
                customer_id = '',
                customer_email = '',
                customer_creation = 'always',
                line_items = [
                    payjpv2.models.line_item_request.LineItemRequest(
                        price_id = '', 
                        quantity = 56, 
                        tax_rates = [
                            ''
                            ], )
                    ],
                metadata = {
                    'key' : null
                    },
                success_url = '',
                cancel_url = '',
                currency = 'jpy',
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                locale = 'auto',
                payment_method_types = [
                    'card'
                    ],
                payment_method_options = payjpv2.models.checkout_session_payment_method_options_request.CheckoutSessionPaymentMethodOptionsRequest(
                    card = payjpv2.models.checkout_session_payment_method_options_card_request.CheckoutSessionPaymentMethodOptionsCardRequest(
                        request_extended_authorization = 'if_available', 
                        request_three_d_secure = 'any', ), ),
                payment_flow_data = payjpv2.models.payment_flow_data_request.PaymentFlowDataRequest(
                    capture_method = 'automatic', 
                    metadata = {
                        'key' : null
                        }, ),
                submit_type = 'auto',
                setup_flow_data = payjpv2.models.setup_flow_data_request.SetupFlowDataRequest(
                    metadata = {
                        'key' : null
                        }, ),
                ui_mode = 'hosted'
            )
        else:
            return CheckoutSessionCreateRequest(
                mode = 'payment',
        )
        """

    def testCheckoutSessionCreateRequest(self):
        """Test CheckoutSessionCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.4"

# import apis into sdk package
from payjpv2.api.balances_api import BalancesApi
from payjpv2.api.checkout_sessions_api import CheckoutSessionsApi
from payjpv2.api.customers_api import CustomersApi
from payjpv2.api.events_api import EventsApi
from payjpv2.api.payment_refunds_api import PaymentRefundsApi
from payjpv2.api.payment_flows_api import PaymentFlowsApi
from payjpv2.api.payment_method_configurations_api import PaymentMethodConfigurationsApi
from payjpv2.api.payment_methods_api import PaymentMethodsApi
from payjpv2.api.payment_transactions_api import PaymentTransactionsApi
from payjpv2.api.prices_api import PricesApi
from payjpv2.api.products_api import ProductsApi
from payjpv2.api.setup_flows_api import SetupFlowsApi
from payjpv2.api.statements_api import StatementsApi
from payjpv2.api.tax_rates_api import TaxRatesApi
from payjpv2.api.terms_api import TermsApi

# import ApiClient
from payjpv2.api_response import ApiResponse
from payjpv2.api_client import ApiClient
from payjpv2.configuration import Configuration
from payjpv2.exceptions import OpenApiException
from payjpv2.exceptions import ApiTypeError
from payjpv2.exceptions import ApiValueError
from payjpv2.exceptions import ApiKeyError
from payjpv2.exceptions import ApiAttributeError
from payjpv2.exceptions import ApiException

# import models into sdk package
from payjpv2.models.balance_list_response import BalanceListResponse
from payjpv2.models.balance_response import BalanceResponse
from payjpv2.models.balance_state import BalanceState
from payjpv2.models.balance_url_response import BalanceURLResponse
from payjpv2.models.bank_info_response import BankInfoResponse
from payjpv2.models.capture_method import CaptureMethod
from payjpv2.models.card_config_request import CardConfigRequest
from payjpv2.models.checkout_session_create_request import CheckoutSessionCreateRequest
from payjpv2.models.checkout_session_customer_details_address_response import CheckoutSessionCustomerDetailsAddressResponse
from payjpv2.models.checkout_session_customer_details_response import CheckoutSessionCustomerDetailsResponse
from payjpv2.models.checkout_session_details_response import CheckoutSessionDetailsResponse
from payjpv2.models.checkout_session_line_item_data_response import CheckoutSessionLineItemDataResponse
from payjpv2.models.checkout_session_line_item_list_response import CheckoutSessionLineItemListResponse
from payjpv2.models.checkout_session_list_response import CheckoutSessionListResponse
from payjpv2.models.checkout_session_mode import CheckoutSessionMode
from payjpv2.models.checkout_session_payment_method_options_card_request import CheckoutSessionPaymentMethodOptionsCardRequest
from payjpv2.models.checkout_session_payment_method_options_request import CheckoutSessionPaymentMethodOptionsRequest
from payjpv2.models.checkout_session_status import CheckoutSessionStatus
from payjpv2.models.checkout_session_submit_type import CheckoutSessionSubmitType
from payjpv2.models.checkout_session_ui_mode import CheckoutSessionUIMode
from payjpv2.models.checkout_session_update_request import CheckoutSessionUpdateRequest
from payjpv2.models.country import Country
from payjpv2.models.currency import Currency
from payjpv2.models.customer_create_request import CustomerCreateRequest
from payjpv2.models.customer_creation import CustomerCreation
from payjpv2.models.customer_list_response import CustomerListResponse
from payjpv2.models.customer_response import CustomerResponse
from payjpv2.models.customer_update_request import CustomerUpdateRequest
from payjpv2.models.display_preference_request import DisplayPreferenceRequest
from payjpv2.models.error_response import ErrorResponse
from payjpv2.models.event_list_response import EventListResponse
from payjpv2.models.event_response import EventResponse
from payjpv2.models.line_item_request import LineItemRequest
from payjpv2.models.locale import Locale
from payjpv2.models.metadata_value import MetadataValue
from payjpv2.models.pay_pay_config_request import PayPayConfigRequest
from payjpv2.models.payment_flow_cancel_request import PaymentFlowCancelRequest
from payjpv2.models.payment_flow_cancellation_reason import PaymentFlowCancellationReason
from payjpv2.models.payment_flow_capture_request import PaymentFlowCaptureRequest
from payjpv2.models.payment_flow_confirm_request import PaymentFlowConfirmRequest
from payjpv2.models.payment_flow_create_request import PaymentFlowCreateRequest
from payjpv2.models.payment_flow_data_request import PaymentFlowDataRequest
from payjpv2.models.payment_flow_list_response import PaymentFlowListResponse
from payjpv2.models.payment_flow_payment_method_options_card_request import PaymentFlowPaymentMethodOptionsCardRequest
from payjpv2.models.payment_flow_payment_method_options_request import PaymentFlowPaymentMethodOptionsRequest
from payjpv2.models.payment_flow_response import PaymentFlowResponse
from payjpv2.models.payment_flow_status import PaymentFlowStatus
from payjpv2.models.payment_flow_update_request import PaymentFlowUpdateRequest
from payjpv2.models.payment_method_apple_pay_create_request import PaymentMethodApplePayCreateRequest
from payjpv2.models.payment_method_apple_pay_update_request import PaymentMethodApplePayUpdateRequest
from payjpv2.models.payment_method_attach_request import PaymentMethodAttachRequest
from payjpv2.models.payment_method_billing_address_request import PaymentMethodBillingAddressRequest
from payjpv2.models.payment_method_billing_address_response import PaymentMethodBillingAddressResponse
from payjpv2.models.payment_method_billing_details_request import PaymentMethodBillingDetailsRequest
from payjpv2.models.payment_method_billing_details_response import PaymentMethodBillingDetailsResponse
from payjpv2.models.payment_method_card_billing_details_request import PaymentMethodCardBillingDetailsRequest
from payjpv2.models.payment_method_card_create_request import PaymentMethodCardCreateRequest
from payjpv2.models.payment_method_card_details_response import PaymentMethodCardDetailsResponse
from payjpv2.models.payment_method_card_response import PaymentMethodCardResponse
from payjpv2.models.payment_method_card_update_request import PaymentMethodCardUpdateRequest
from payjpv2.models.payment_method_configuration_details_response import PaymentMethodConfigurationDetailsResponse
from payjpv2.models.payment_method_configuration_display_preference import PaymentMethodConfigurationDisplayPreference
from payjpv2.models.payment_method_configuration_list_response import PaymentMethodConfigurationListResponse
from payjpv2.models.payment_method_configuration_setting_response import PaymentMethodConfigurationSettingResponse
from payjpv2.models.payment_method_configuration_update_request import PaymentMethodConfigurationUpdateRequest
from payjpv2.models.payment_method_create_card_details_request import PaymentMethodCreateCardDetailsRequest
from payjpv2.models.payment_method_create_request import PaymentMethodCreateRequest
from payjpv2.models.payment_method_list_response import PaymentMethodListResponse
from payjpv2.models.payment_method_pay_pay_create_request import PaymentMethodPayPayCreateRequest
from payjpv2.models.payment_method_pay_pay_response import PaymentMethodPayPayResponse
from payjpv2.models.payment_method_pay_pay_update_request import PaymentMethodPayPayUpdateRequest
from payjpv2.models.payment_method_response import PaymentMethodResponse
from payjpv2.models.payment_method_types import PaymentMethodTypes
from payjpv2.models.payment_method_update_request import PaymentMethodUpdateRequest
from payjpv2.models.payment_refund_create_request import PaymentRefundCreateRequest
from payjpv2.models.payment_refund_list_response import PaymentRefundListResponse
from payjpv2.models.payment_refund_reason import PaymentRefundReason
from payjpv2.models.payment_refund_response import PaymentRefundResponse
from payjpv2.models.payment_refund_status import PaymentRefundStatus
from payjpv2.models.payment_refund_update_request import PaymentRefundUpdateRequest
from payjpv2.models.payment_transaction_list_response import PaymentTransactionListResponse
from payjpv2.models.payment_transaction_response import PaymentTransactionResponse
from payjpv2.models.payment_transaction_type import PaymentTransactionType
from payjpv2.models.price_create_request import PriceCreateRequest
from payjpv2.models.price_details_response import PriceDetailsResponse
from payjpv2.models.price_list_response import PriceListResponse
from payjpv2.models.price_type import PriceType
from payjpv2.models.price_update_request import PriceUpdateRequest
from payjpv2.models.product_create_request import ProductCreateRequest
from payjpv2.models.product_deleted_response import ProductDeletedResponse
from payjpv2.models.product_details_response import ProductDetailsResponse
from payjpv2.models.product_list_response import ProductListResponse
from payjpv2.models.product_update_request import ProductUpdateRequest
from payjpv2.models.setup_flow_cancel_request import SetupFlowCancelRequest
from payjpv2.models.setup_flow_cancellation_reason import SetupFlowCancellationReason
from payjpv2.models.setup_flow_create_request import SetupFlowCreateRequest
from payjpv2.models.setup_flow_data_request import SetupFlowDataRequest
from payjpv2.models.setup_flow_list_response import SetupFlowListResponse
from payjpv2.models.setup_flow_payment_method_options_card_request import SetupFlowPaymentMethodOptionsCardRequest
from payjpv2.models.setup_flow_payment_method_options_request import SetupFlowPaymentMethodOptionsRequest
from payjpv2.models.setup_flow_response import SetupFlowResponse
from payjpv2.models.setup_flow_status import SetupFlowStatus
from payjpv2.models.setup_flow_update_request import SetupFlowUpdateRequest
from payjpv2.models.statement_item_response import StatementItemResponse
from payjpv2.models.statement_list_response import StatementListResponse
from payjpv2.models.statement_response import StatementResponse
from payjpv2.models.statement_subject import StatementSubject
from payjpv2.models.statement_type import StatementType
from payjpv2.models.statement_url_response import StatementURLResponse
from payjpv2.models.tax_rate_create_request import TaxRateCreateRequest
from payjpv2.models.tax_rate_details_response import TaxRateDetailsResponse
from payjpv2.models.tax_rate_list_response import TaxRateListResponse
from payjpv2.models.tax_rate_update_request import TaxRateUpdateRequest
from payjpv2.models.term_list_response import TermListResponse
from payjpv2.models.term_response import TermResponse
from payjpv2.models.usage import Usage
